@@ -2,6 +2,7 @@
 # Distributed under the terms of the GNU AGPL License.
 from .ntypes import t_tz, error_busy, error_reject, copy_button
 from IPython.core.display import display, Javascript, HTML
+from IPython.display import IFrame
 from .runner.notifications import Notifications
 from .dependency import Dependency
 from .runner.env_var import n_env
@@ -16,7 +17,7 @@ import requests
 import os
 import sys
 
-__version__ = "1.11.5"
+__version__ = "1.12.1"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -116,9 +117,13 @@ def __open_canny_board(board_id, email, name, uid):
     display(HTML(data))
 
 
+def manager():
+    display(IFrame(f"{n_env.user_url}/naas", width="100%", height="800"))
+
+
 def bug_report():
     email = str(n_env.user)
-    name = email.split("@")[0].split(".").join(" ")
+    name = " ".join(email.split("@")[0].split("."))
     uid = email.split("@")[0].replace(".", "")
     board_id = "6a83d5c5-2165-2608-082d-49959c7f030c"
     __open_canny_board(board_id, email, name, uid)
@@ -127,7 +132,7 @@ def bug_report():
 def feature_request():
     email = str(n_env.user)
     uid = email.split("@")[0].replace(".", "")
-    name = email.split("@")[0].split(".").join(" ")
+    name = " ".join(email.split("@")[0].split("."))
     board_id = "e3e3e0c3-7520-47f5-56f5-39182fb70480"
     __open_canny_board(board_id, email, name, uid)
 
